@@ -3,7 +3,6 @@ from django.db import models
 from django.utils.safestring import mark_safe
 from django.utils.html import linebreaks, urlize
 from django.utils.functional import curry
-from django.core.exceptions import ImproperlyConfigured
 import widgets
 
 _rendered_field_name = lambda name: '_%s_rendered' % name
@@ -28,7 +27,7 @@ try:
 
         DEFAULT = HtmlFormatter()
         VARIANTS = {
-            'linenos': HtmlFormatter(linenos=True)
+            'linenos': HtmlFormatter(linenos=True),
         }
 
         def pygments_directive(name, arguments, options, content, lineno,
@@ -162,8 +161,8 @@ class MarkupField(models.TextField):
         self.default_markup_type = markup_type or default_markup_type
         if (self.default_markup_type and
             self.default_markup_type not in _MARKUP_TYPES):
-            raise ValueError('Invalid markup type, allowed values: %s' %
-                             ', '.join(_MARKUP_TYPES.iterkeys()))
+            raise ValueError("Invalid markup type for field '%s', allowed values: %s" %
+                             (name, ', '.join(_MARKUP_TYPES.iterkeys())))
         self.markup_type_editable = markup_type is None
         super(MarkupField, self).__init__(verbose_name, name, **kwargs)
 
@@ -193,6 +192,7 @@ class MarkupField(models.TextField):
         return value.raw
 
     def get_db_prep_value(self, value):
+        # for Django 1.2+ rename this to get_prep_value
         if isinstance(value, Markup):
             return value.raw
         else:
